@@ -37,6 +37,7 @@
 #include <librnd/core/buildin.hidlib.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/plugins.h>
+#include <librnd/poly/polyarea.h>
 
 /* local (app) headers */
 #include "gui_act.h"
@@ -56,10 +57,10 @@
 
 static const char *EXPERIMENTAL = NULL;
 
-static const char *menu_file_paths[] = { "./", "~/.camv-rnd/", NULL, NULL };
+static const char *menu_file_paths[] = { "./", "~/" DOT_CAMV_RND "/", NULL, NULL };
 static const char *menu_name_fmt = "menu.lht";
 
-#define CONF_USER_DIR "~/.camv-rnd"
+#define CONF_USER_DIR "~/" DOT_CAMV_RND
 
 const char *rnd_conf_userdir_path = CONF_USER_DIR;
 const char *rnd_conf_user_path = CONF_USER_DIR "/conf_core.lht";
@@ -102,7 +103,7 @@ const char *camv_action_args[] = {
 	NULL, NULL, NULL, NULL, NULL /* terminator */
 };
 
-static void camv_main_uninit(void)
+void camv_main_uninit(void)
 {
 	gui_support_plugins(0);
 	camv_design_free_fields(&camv);
@@ -113,6 +114,7 @@ static void camv_main_init(void)
 	camv_plug_io_act_init();
 }
 
+
 int main(int argc, char *argv[])
 {
 	int n;
@@ -208,5 +210,13 @@ TODO("action list");
 	camv_crosshair_gui_uninit();
 	camv_main_uninit();
 	rnd_main_args_uninit(&ga);
+
+	{ /* make sure -lrnd-poly really includes it */
+		rnd_pline_t pl;
+		rnd_vnode_t v;
+		pl.head = &v;
+		rnd_poly_contour_init(&pl);
+	}
+
 	return 0;
 }
