@@ -43,8 +43,12 @@ void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xf
 	rnd_cardinal_t lid;
 	rnd_hid_gc_t gc;
 	int clearing = -1, direct = 1, need_flush = 0;
+	rnd_hid_t *save = rnd_render;
+	
+	if ((rnd_render != NULL) && (!rnd_render->override_render))
+		rnd_render = hid;
 
-	gc = rnd_gui->make_gc(rnd_gui);
+	gc = rnd_render->make_gc(rnd_render);
 
 	/* calculate whether the cheaper direct-draw mechanism can be done */
 	for(lid = 0; lid < camv.layers.used; lid++) {
@@ -57,7 +61,7 @@ void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xf
 	}
 
 	/* announce start of rendering */
-	rnd_gui->render_burst(rnd_gui, RND_HID_BURST_START, &region->view);
+	rnd_render->render_burst(rnd_render, RND_HID_BURST_START, &region->view);
 
 	/* the HID needs a group set, even if we don't do groups */
 	if (rnd_render->set_layer_group != NULL)
@@ -68,10 +72,10 @@ void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xf
 		if (!ly->vis) continue;
 		if (!ly->sub) {
 			if (need_flush) {
-				rnd_gui->set_drawing_mode(rnd_gui, RND_HID_COMP_FLUSH, direct, &region->view);
+				rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_FLUSH, direct, &region->view);
 				rnd_render->end_layer(rnd_render);
 			}
-			rnd_gui->set_drawing_mode(rnd_gui, RND_HID_COMP_RESET, direct, &region->view);
+			rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_RESET, direct, &region->view);
 			need_flush = 1;
 
 
@@ -79,19 +83,21 @@ void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xf
 
 		if (((int)ly->clearing != clearing) || (!ly->sub)) {
 			clearing = ly->clearing;
-			rnd_gui->set_drawing_mode(rnd_gui, ly->clearing ? RND_HID_COMP_NEGATIVE : RND_HID_COMP_POSITIVE, direct, &region->view);
+			rnd_render->set_drawing_mode(rnd_render, ly->clearing ? RND_HID_COMP_NEGATIVE : RND_HID_COMP_POSITIVE, direct, &region->view);
 		}
-		rnd_gui->set_color(gc, &ly->color);
+		rnd_render->set_color(gc, &ly->color);
 		camv_draw_layer(ly, gc, region, xform_caller);
 	}
 
 	if (need_flush) {
-		rnd_gui->set_drawing_mode(rnd_gui, RND_HID_COMP_FLUSH, direct, &region->view);
+		rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_FLUSH, direct, &region->view);
 		rnd_render->end_layer(rnd_render);
 	}
 
-	rnd_gui->render_burst(rnd_gui, RND_HID_BURST_END, &region->view);
-	rnd_gui->destroy_gc(gc);
+	rnd_render->render_burst(rnd_render, RND_HID_BURST_END, &region->view);
+	rnd_render->destroy_gc(gc);
+
+	rnd_render = save;
 }
 
 void camv_expose_preview(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *e)
