@@ -34,6 +34,7 @@
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
 #include "data.h"
+#include "build_run.h"
 
 /* print usage lines */
 static inline void u(const char *fmt, ...)
@@ -88,7 +89,7 @@ static int help_invoc(void)
 {
 	rnd_hid_t **hl = rnd_hid_enumerate();
 	int i;
-	int n_printer = 0, n_gui = 0, n_exporter = 0;
+	int n_printer = 0, n_exporter = 0;
 
 	u("camv-rnd invocation:");
 	u("");
@@ -96,10 +97,8 @@ static int help_invoc(void)
 	u("");
 	u("camv-rnd [generics] [--gui GUI] [gui options] <cam file>   interactive GUI");
 
-	u("Available GUI hid%s:", n_gui == 1 ? "" : "s");
-	for (i = 0; hl[i]; i++)
-		if (hl[i]->gui)
-			fprintf(stderr, "\t%-8s %s\n", hl[i]->name, hl[i]->description);
+	u("Available GUI HIDs:");
+	rnd_hid_print_all_gui_plugins();
 
 /*
 	u("\ncamv-rnd [generics] -p [printing options] <cam file>\tto print");
@@ -157,7 +156,7 @@ static const char camv_acts_PrintVersion[] = "PrintVersion()";
 static const char camv_acth_PrintVersion[] = "Print version.";
 fgw_error_t camv_act_PrintVersion(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	printf("camv-rnd " CAMV_VERS "\n");
+	printf("%s\n", camv_rnd_get_info_program());
 	RND_ACT_IRES(0);
 	return 0;
 }
