@@ -9,6 +9,8 @@
 void deb_printf(const char *f, ...) {}
 #endif
 
+int ttf2bbox_y_mirror = 1;
+
 int ttf2bbox_init(ttf2bbox_t *lib)
 {
 	memset(lib, 0, sizeof(ttf2bbox_t));
@@ -243,7 +245,7 @@ deb_printf("c: %ld %ld box: %ld %ld s: %ld %ld\n", cx, cy, boxw, boxh, sx, sy);
 		if (FT_Load_Char(face, *s, FT_LOAD_RENDER) != 0)
 			continue;
 
-		draw_bitmap(dst, &slot->bitmap, slot->bitmap_left, dst->sy - slot->bitmap_top - bltune, drx, dry, 1);
+		draw_bitmap(dst, &slot->bitmap, slot->bitmap_left, dst->sy - slot->bitmap_top - bltune, drx, dry, ttf2bbox_y_mirror);
 		pen.x += slot->advance.x;
 		pen.y += slot->advance.y;
 		h = slot->metrics.height;
