@@ -252,15 +252,29 @@ static void layer_unselect(layersel_ctx_t *ls)
 	if (lys != NULL)
 		rnd_gui->attr_dlg_widget_state(ls->sub.dlg_hid_ctx, (*lys)->wlab, 1);
 	ls->selected = -1;
+	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", ls->selected);
+}
+
+static void layer_select_idx(layersel_ctx_t *ls, int idx)
+{
+	ls_layer_t **lys;
+	layer_unselect(ls);
+	lys = (ls_layer_t **)vtp0_get(&ls->layers, idx, 0);
+	if (lys != NULL) {
+		rnd_gui->attr_dlg_widget_state(ls->sub.dlg_hid_ctx, (*lys)->wlab, 2);
+		ls->selected = idx;
+	}
+	else
+		ls->selected = -1;
+	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", ls->selected);
 }
 
 static void layer_select(ls_layer_t *lys)
 {
-	layer_unselect(lys->ls);
-	lys->ls->selected = lys->lid;
-	rnd_gui->attr_dlg_widget_state(lys->ls->sub.dlg_hid_ctx, lys->wlab, 2);
+	layer_select_idx(lys->ls, lys->lid);
 }
 
+
 static void layer_sel_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	layer_select((ls_layer_t *)attr->user_data);
@@ -498,9 +512,29 @@ static void layer_del(void)
 
 	layersel.selected = -1;
 	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYERS_CHANGED, NULL);
+	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", layersel.selected);
 	camv_hid_redraw(layersel.camv);
 }
 
+static void layer_set_color(const rnd_color_t clr)
+{
+	int src = layersel.selected;
+	camv_layer_t *ly = layersel.camv->layers.array[src];
+
+	ly->color = clr;
+	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYERS_CHANGED, NULL);
+}
+
+static void layer_rename(const char *name)
+{
+	int src = layersel.selected;
+	camv_layer_t *ly = layersel.camv->layers.array[src];
+
+	free(ly->short_name);
+	ly->short_name = rnd_strdup(name);
+	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYERS_CHANGED, NULL);
+}
+
 static void layer_del_all(void)
 {
 	long n;
@@ -514,6 +548,7 @@ static void layer_del_all(void)
 
 	layersel.selected = -1;
 	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYERS_CHANGED, NULL);
+	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", layersel.selected);
 	camv_hid_redraw(layersel.camv);
 }
 
@@ -528,14 +563,15 @@ static void all_vis(camv_design_t *camv, int vis)
 	camv_hid_redraw(layersel.camv);
 }
 
-const char camv_acts_Layer[] = "Layer([up|down|top|bottom|del])";
-const char camv_acth_Layer[] = "Move or remove the current layer\n";
+/* DOC: layer.html */
+const char camv_acts_Layer[] = "Layer([up|down|top|bottom|del|getidx|getlen|setcolor|rename])";
+const char camv_acth_Layer[] = "Move or remove the current layer or return index\n";
 fgw_error_t camv_act_Layer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	const char *cmd = NULL;
+	const char *cmd = NULL, *clrstr, *name;
 	camv_design_t *camv = layersel.camv;
 
-	if (argc != 2)
+	if ((argc != 2) && (argc != 3))
 		RND_ACT_FAIL(Layer);
 
 	RND_ACT_CONVARG(1, FGW_STR, Layer, cmd = argv[1].val.str);
@@ -574,6 +610,37 @@ fgw_error_t camv_act_Layer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		if (layersel.selected < 0) goto nolayer;
 		layer_del_all();
 	}
+	else if (rnd_strcasecmp(cmd, "getidx") == 0) {
+		RND_ACT_IRES(layersel.selected);
+		return 0;
+	}
+	else if (rnd_strcasecmp(cmd, "select") == 0) {
+		int idx;
+		RND_ACT_CONVARG(2, FGW_INT, Layer, idx = argv[2].val.nat_int);
+		layer_select_idx(&layersel, idx);
+		return 0;
+	}
+	else if (rnd_strcasecmp(cmd, "getlen") == 0) {
+		RND_ACT_IRES(camv->layers.used);
+		return 0;
+	}
+	else if (rnd_strcasecmp(cmd, "setcolor") == 0) {
+		rnd_color_t clr;
+
+		RND_ACT_CONVARG(2, FGW_STR, Layer, clrstr = argv[2].val.str);
+		if (rnd_color_load_str(&clr, clrstr) != 0) {
+			rnd_message(RND_MSG_ERROR, "Invalid color in Layer(setcolor): '%s'\b", clrstr);
+			RND_ACT_IRES(-1);
+			return 0;
+		}
+
+		layer_set_color(clr);
+	}
+	else if (rnd_strcasecmp(cmd, "rename") == 0) {
+		RND_ACT_CONVARG(2, FGW_STR, Layer, name = argv[2].val.str);
+		layer_rename(name);
+	}
+
 	else {
 		RND_ACT_FAIL(Layer);
 	}
