@@ -49,6 +49,7 @@ typedef struct {
 	unsigned int inbody:1;
 	unsigned int started:1; /* M48 detected */
 	unsigned int got_unit:1;
+	unsigned int leading_zero:1;
 
 	/* dynamic */
 	unsigned int rout:1;
@@ -82,18 +83,63 @@ static inline rnd_coord_t exc2coord(exc_t *exc, double d)
 static double exc_strtod(exc_t *exc, const char *str, char **end)
 {
 	const char *s;
-	int len, has_dot = 0;
-	double res = strtod(str, end);
+	char tmp[32], *start, *o;
+	int len, has_dot = 0, neg = 0;
+	double res;
 
-	for(s = str, len = 0; s < *end; s++,len++)
+	/* copy digits and dots to start, which is in the middle of tmp so it
+	   can be easily extended in both directions */
+	start = o = tmp+16;
+	if (*str == '-') {
+		neg = 1;
+		str++;
+	}
+	for(s = str, len = 0; (isdigit(*s) || (*s == '.')); s++,len++) {
 		if (*s == '.')
 			has_dot = 1;
+		*o = *s;
+		o++;
+		if (len > 14) {
+			rnd_message(RND_MSG_ERROR, "excellon: invalid coord '%s' (too long)\n", str);
+			return 0;
+		}
+	}
+	*end = (char *)s;
+	*o = '\0';
 
-	if (exc->inch && (len == 6) && !has_dot) {
+	/* make sure we have exactly 6 digits */
+	if (len < 6) {
+		if (exc->leading_zero) {
+			while(len < 6) {
+				*o = '0';
+				o++;
+				len++;
+			}
+			*o = '\0';
+		}
+		else {
+			while(len < 6) {
+				start--;
+				*start = '0';
+				len++;
+			}
+		}
+	}
+	else if (len > 6)
+		start[6] = '\0';
+
+
+	res = strtod(start, NULL);
+	if (neg)
+		res = -res;
+
+/*	printf("CNC C: '%s' -> '%s' -> %f end='%s'\n", str, start, res, *end);*/
+
+	if (exc->inch && !has_dot) {
 		/* old INCH format with no decimal point: 00.0000 format */
 		res /= 10000.0;
 	}
-	if (!exc->inch && exc->has_metric_scale && !has_dot) {
+	else if (!exc->inch && exc->has_metric_scale && !has_dot) {
 		/* METRIC,00.000 flexible format */
 		res /= exc->metric_scale;
 	}
@@ -205,11 +251,19 @@ static int exc_parse_header(exc_t *exc, char **line)
 		(*line) += 4;
 		if (exc->got_unit)
 			goto err_unit_dup;
+
+
 		exc->inch = 1;
 		exc->got_unit = 1;
 		return 0;
 	}
 
+	if (strncmp(*line, ",LZ", 3) == 0) {
+		exc->leading_zero = 1;
+		(*line) += 3;
+		return 0;
+	}
+
 	if ((*line)[0] == 'T') {
 		char *end;
 		long idx;
@@ -220,7 +274,8 @@ static int exc_parse_header(exc_t *exc, char **line)
 			rnd_message(RND_MSG_ERROR, "excellon: tool index %d out of range (0..99)\n", idx);
 			return -1;
 		}
-		if (*end != 'C') {
+		end = strchr(end, 'C'); /* skip over S and F */
+		if ((end == NULL) || (*end != 'C')) {
 			rnd_message(RND_MSG_ERROR, "excellon: tool separator 'C' is missing\n");
 			return -1;
 		}
@@ -238,20 +293,27 @@ static int exc_parse_header(exc_t *exc, char **line)
 
 static int exc_parse_move(exc_t *exc, char **line, char endchar)
 {
-	double x, y;
-	if (**line != 'X') {
-		rnd_message(RND_MSG_ERROR, "excellon: expected X\n");
-		return -1;
-	}
-	(*line)++;
-	x = exc_strtod(exc, *line, line);
+	double x = exc->x, y = exc->y;
 
-	if (**line != 'Y') {
-		rnd_message(RND_MSG_ERROR, "excellon: expected Y (broken X coord?)\n");
-		return -1;
+	if (**line != 'Y') { /* X is optional, when missing, Y starts the line */
+		if (**line != 'X') {
+			rnd_message(RND_MSG_ERROR, "excellon: expected X\n");
+			return -1;
+		}
+		(*line)++;
+		x = exc_strtod(exc, *line, line);
+		exc->x = exc2coord(exc, x);
+	}
+
+	if (**line != '\0') { /* Y is optional */
+		if (**line != 'Y') {
+			rnd_message(RND_MSG_ERROR, "excellon: expected Y (broken X coord?)\n");
+			return -1;
+		}
+		(*line)++;
+		y = exc_strtod(exc, *line, line);
+		exc->y = exc2coord(exc, y);
 	}
-	(*line)++;
-	y = exc_strtod(exc, *line, line);
 
 	if (endchar != '\0') { /* requested specific termination */
 		if (**line != endchar) {
@@ -260,8 +322,6 @@ static int exc_parse_move(exc_t *exc, char **line, char endchar)
 		}
 	}
 
-	exc->x = exc2coord(exc, x);
-	exc->y = exc2coord(exc, y);
 	return 0;
 }
 
@@ -369,13 +429,15 @@ static int exc_parse_body(exc_t *exc, char **line)
 		return 0;
 	}
 
-	if ((*line)[0] == 'X') {
+	if (((*line)[0] == 'X') || ((*line)[0] == 'Y')) {
 		if (exc->tool == 0) {
 			rnd_message(RND_MSG_ERROR, "excellon: can not drill: no tool selected\n");
 			return -1;
 		}
-		if (exc_parse_move(exc, line, '\0') != 0)
+		if (exc_parse_move(exc, line, '\0') != 0) {
+			rnd_message(RND_MSG_ERROR, "excellon: exc_parse_move() failed\n");
 			return -1;
+		}
 		exc_gen_line(exc, exc->x, exc->y, exc->x, exc->y);
 		return 0;
 	}
