@@ -472,6 +472,9 @@ int gexlex(YYSTYPE *lval, ge_expr_prglist_t *ctx_)
 	return c;
 }
 
+TODO("switch over from byacc to byaccic and have a .h");
+int gexparse(ge_expr_prglist_t *lst);
+
 static int geparse_macro_expr(geparse_ctx_t *ctx, ge_expr_prg_t **res) {
 	int r;
 	ge_expr_prglist_t lst;
