@@ -667,10 +667,15 @@ static int gedraw_aper_store(gedraw_ctx_t *ctx, long aid, const ge_aper_t *aper)
 		ctx->aper_inited = 1;
 	}
 
-	if (htip_has(&ctx->aper, aid)) {
-		rnd_message(RND_MSG_ERROR, "gedraw_aper_store: aperture %ld is defuned multiple times\n", aid);
-		return -1;
+	if (htip_has(&ctx->aper, aid)) { 
+		static int explained = 0;
+		rnd_message(RND_MSG_WARNING, "gedraw_aper_store: aperture %ld is re-defined\n", aid);
+		if (!explained) {
+			rnd_message(RND_MSG_WARNING, "This is not necessarily an error, but is probably bad\npractice and is dangerous: some gerber viewers will break on this\n", aid);
+			explained = 1;
+		}
 	}
+
 	htip_set(&ctx->aper, aid, (ge_aper_t *)aper); /* can remember by pointer because it's coming from the VM code */
 	return 0;
 }
@@ -688,6 +693,7 @@ typedef struct {
 	long aper;
 	ge_interp_t interp;
 	ge_quadr_t quadr;
+	long sets; /* number of set instructions within the block */
 	unsigned relcrd:1;
 	unsigned relat:1;
 	unsigned poly:1;
@@ -943,7 +949,7 @@ static void gedraw_do_draw_arc(camv_design_t *camv, gedraw_ctx_t *ctx, camv_laye
 
 	r1 = rnd_distance(last->x, last->y, cx, cy);
 	r2 = rnd_distance(curr->x, curr->y, cx, cy);
-	if (fabs(r1 - r2) > 2*ctx->acceptable_error)
+	if (RND_ABS(r1 - r2) > 2*ctx->acceptable_error)
 		rnd_message(RND_MSG_ERROR, "gedraw_do: DRAW arc: not circular: radius %.6mm vs. %.6mm\n", (rnd_coord_t)rnd_round(r1), (rnd_coord_t)rnd_round(r2));
 
 	if (curr->poly) {
@@ -1024,12 +1030,15 @@ static void gedraw_do(camv_design_t *camv, gedraw_ctx_t *ctx, const camv_layer_t
 		case GEC_FLASH:      gedraw_do_flash(camv, ctx, *ly, curr, last); break;
 
 		case GEC_invalid:
-			rnd_message(RND_MSG_ERROR, "gedraw_do: invalid opcode %d (uninitialized) \n", curr->op);
+			if (!curr->sets)
+				rnd_message(RND_MSG_WARNING, "gedraw_do: invalid opcode %d (uninitialized #1; probably an empty command sequence terminated by a '*')\n", curr->op);
+			/* else the command sequence did set some states, so it is okay */
 			break;
 		default:
-			rnd_message(RND_MSG_ERROR, "gedraw_do: invalid opcode %d (unrecognized)\n", curr->op);
+			rnd_message(RND_MSG_ERROR, "gedraw_do: invalid opcode %d (unrecognized #1)\n", curr->op);
 	}
 	memcpy(last, curr, sizeof(gerbst_t));
+	curr->sets = 0;
 }
 
 static int gedraw_camv_(camv_design_t *camv, gedraw_ctx_t *ctx, const camv_layer_t *main_layer, camv_layer_t **layer, size_t *from, int in_sr, gerbst_t *curr, gerbst_t *last)
@@ -1042,19 +1051,20 @@ static int gedraw_camv_(camv_design_t *camv, gedraw_ctx_t *ctx, const camv_layer
 		switch(i->cmd) {
 			case GEC_MACRO_DEF:  break; /* shouldn't happen */
 
-			case GEC_SET_X:      SETCRD(curr->x, i->data.coord); break;
-			case GEC_SET_Y:      SETCRD(curr->y, i->data.coord); break;
-			case GEC_SET_I:      SETCRD(curr->i, i->data.coord); break;
-			case GEC_SET_J:      SETCRD(curr->j, i->data.coord); break;
-			case GEC_SET_RELAT:  curr->relat = i->data.on; break;
-			case GEC_SET_RELCRD: curr->relcrd = i->data.on; break;
-			case GEC_SET_INTERP: curr->interp = i->data.interp; break;
-			case GEC_SET_QUADR:  curr->quadr = i->data.quadr; break;
+			case GEC_SET_X:      SETCRD(curr->x, i->data.coord); curr->sets++; break;
+			case GEC_SET_Y:      SETCRD(curr->y, i->data.coord); curr->sets++; break;
+			case GEC_SET_I:      SETCRD(curr->i, i->data.coord); curr->sets++; break;
+			case GEC_SET_J:      SETCRD(curr->j, i->data.coord); curr->sets++; break;
+			case GEC_SET_RELAT:  curr->relat = i->data.on; curr->sets++; break;
+			case GEC_SET_RELCRD: curr->relcrd = i->data.on; curr->sets++; break;
+			case GEC_SET_INTERP: curr->interp = i->data.interp; curr->sets++; break;
+			case GEC_SET_QUADR:  curr->quadr = i->data.quadr; curr->sets++; break;
 
 			case GEC_SET_POLY:
 				if ((curr->poly) && (!i->data.on))
 					gedraw_poly_close(camv, ctx, ly);
 				curr->poly = i->data.on;
+				curr->sets++;
 				break;
 
 			case GEC_APER_DEF:
@@ -1079,7 +1089,7 @@ static int gedraw_camv_(camv_design_t *camv, gedraw_ctx_t *ctx, const camv_layer
 			case GEC_DO:         gedraw_do(camv, ctx, main_layer, &ly, curr, last); break;
 
 			case GEC_invalid:
-				rnd_message(RND_MSG_ERROR, "gedraw_camv: invalid opcode %d (uninitialized) \n", i->cmd);
+				rnd_message(RND_MSG_ERROR, "gedraw_camv: invalid opcode %d (uninitialized #2) \n", i->cmd);
 				break;
 
 			case GEC_STEPREP:
@@ -1142,10 +1152,11 @@ static int gedraw_camv(camv_design_t *camv, gedraw_ctx_t *ctx, const char *name)
 {
 	size_t from = 0;
 	camv_layer_t *ly = camv_layer_new();
+	gerbst_t curr, last;
+
 	ly->name = rnd_strdup(name);
 	camv_layer_invent_color(camv, ly); /* gerber files do not have layer color */
 	camv_layer_append_to_design(camv, ly);
-	gerbst_t curr, last;
 
 	memset(&curr, 0, sizeof(curr));
 	curr.interp = GEI_LIN;
